@@ -23,23 +23,26 @@ EXERCISE_DIR=$(cd $(dirname "$0") && pwd)
 TOP_DIR=$(cd $EXERCISE_DIR/..; pwd)
 
 # Import common functions
-source $TOP_DIR/functions
+. $TOP_DIR/functions
 
 # Import configuration
-source $TOP_DIR/openrc
+. $TOP_DIR/openrc
 
 # Import exercise configuration
-source $TOP_DIR/exerciserc
+. $TOP_DIR/exerciserc
 
 is_service_enabled sahara || exit 55
 
-if is_ssl_enabled_service "sahara" || is_service_enabled tls-proxy; then
+if is_ssl_enabled_service "sahara" ||\
+    is_ssl_enabled_service "sahara-api" ||\
+    is_service_enabled tls-proxy; then
     SAHARA_SERVICE_PROTOCOL="https"
 fi
 
 SAHARA_SERVICE_PROTOCOL=${SAHARA_SERVICE_PROTOCOL:-$SERVICE_PROTOCOL}
 
-$CURL_GET $SAHARA_SERVICE_PROTOCOL://$SERVICE_HOST:8386/ 2>/dev/null | grep -q 'Auth' || die $LINENO "Sahara API isn't functioning!"
+$CURL_GET $SAHARA_SERVICE_PROTOCOL://$SERVICE_HOST:8386/ 2>/dev/null \
+                | grep -q 'Auth' || die $LINENO "Sahara API isn't functioning!"
 
 set +o xtrace
 echo "*********************************************************************"
