@@ -13,7 +13,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-import mock
+from unittest import mock
+
 from oslo_utils import uuidutils
 import yaml
 
@@ -274,7 +275,7 @@ class TestImages(b.SaharaTestCase):
         uuidutils.generate_uuid.return_value = hash_value
         cls = images.SaharaScriptValidator
         image_arguments = {"distro": 'centos'}
-        cmd = "It's dangerous to go alone. Run this."
+        cmd = b"It's dangerous to go alone. Run this."
         validator = cls(cmd, env_vars=image_arguments.keys(),
                         output_var="distro")
 
