@@ -13,7 +13,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-import mock
+from unittest import mock
 
 from sahara.service.edp.job_binaries import base as jb_base
 from sahara.tests.unit import base
@@ -26,12 +26,12 @@ class _FakeJobBinary(jb_base.JobBinaryType):
 
 class JobBinaryManagerSupportTest(base.SaharaTestCase):
 
-        def setUp(self):
-            super(JobBinaryManagerSupportTest, self).setUp()
-            self.job_binary = _FakeJobBinary()
+    def setUp(self):
+        super(JobBinaryManagerSupportTest, self).setUp()
+        self.job_binary = _FakeJobBinary()
 
-        def test_generate_valid_path(self):
-            jb = mock.Mock()
-            jb.name = 'jb_name.jar'
-            res = self.job_binary._generate_valid_path(jb)
-            self.assertEqual('/tmp/jb_name.jar', res)
+    def test_generate_valid_path(self):
+        jb = mock.Mock()
+        jb.name = 'jb_name.jar'
+        res = self.job_binary._generate_valid_path(jb)
+        self.assertEqual('/tmp/jb_name.jar', res)
